<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
     xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
     xmlns:cov="http://eviware.com/soapui/coverage">
	<xsl:output method="html" encoding="UTF-8"/>
	
	<!--
	     This stylesheet generate a table with coverage statistics for all
	     operations in a soapui project.
	  -->
	  
	<xsl:template match="/cov:projectCoverage">
		<html>
			<head>
				<title>Coverage Report - <xsl:value-of select="cov:name"/></title>
				<link rel="stylesheet" type="text/css" href="coverage.css" />
			</head>
			<body>
				<h1>Coverage Report - <xsl:value-of select="cov:name"/></h1>
				<table>
				   <!-- Table headers: -->
					<tr>
						<td class="tableheader">Element</td>
						<td class="tableheader" colspan="2">Contract Coverage</td>
					</tr>
					
					<tr>
						<td><img src="project.gif"/><xsl:value-of select="cov:name"/></td>
						
						<xsl:call-template name="coverageCells">
							<xsl:with-param name="element" select="."/>
						</xsl:call-template>
					</tr>	

					<xsl:apply-templates select="cov:interface"/>
				</table>
			</body>
		</html>
	</xsl:template>
	
	<xsl:template match="cov:interface">
		<tr>
			<td><img src="interface2.gif"/><xsl:value-of select="cov:name"/></td>
			
			<xsl:call-template name="coverageCells">
				<xsl:with-param name="element" select="."/>
			</xsl:call-template>
		</tr>	
		<xsl:apply-templates select="cov:operation"/>
	</xsl:template>

	<xsl:template match="cov:operation">
		<tr>
			<td><img src="operation.gif"/><a href="{cov:ref}"><xsl:value-of select="cov:name"/></a></td>

			<xsl:call-template name="coverageCells">
				<xsl:with-param name="element" select="."/>
			</xsl:call-template>
		</tr>
	</xsl:template>

	<xsl:template name="coverageCells">
		<xsl:param name="element"/>
		
		<td align="center">
			<xsl:call-template name="coverage">
				<xsl:with-param name="c" select="$element/cov:contractCoverage"/>
			</xsl:call-template>
		</td>
		<td align="center">
			<xsl:value-of select="$element/cov:contractCoverage/cov:coverage"/>/<xsl:value-of select="$element/cov:contractCoverage/cov:count"/>
		</td>
	</xsl:template>

	<!-- Display CoverageData as a percentage. -->
	<xsl:template name="coverage">
		<xsl:param name="c"/>

		<xsl:choose>
			<xsl:when test="$c/cov:count = 0">
				N/A
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="format-number($c/cov:coverage div $c/cov:count, '0%')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
